import * as cloudfront from '@aws-cdk/aws-cloudfront';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface SimpleWebsiteConfiguration {
    /**
     * Local path to the website folder you want to deploy on S3.
     *
     * @stability stable
     */
    readonly websiteFolder: string;
    /**
     * The index docuement of the website.
     *
     * @stability stable
     */
    readonly indexDoc: string;
    /**
     * The error document of the website.
     *
     * @stability stable
     */
    readonly errorDoc?: string;
    /**
     * Enable encryption for files in your S3 Bucket.
     *
     * @stability stable
     */
    readonly encryptBucket?: boolean;
    /**
     * Hosted Zone used to create the DNS record for the website.
     *
     * @stability stable
     */
    readonly hostedZoneDomain: string;
    /**
     * The domain names you want to deploy.
     *
     * @stability stable
     */
    readonly websiteDomain: string;
    /**
     * The sub-domain name you want to deploy.
     *
     * Default value for a basic website is www
     *
     * @stability stable
     */
    readonly websiteSubDomain?: string;
    /**
     * The price class determines how many edge locations CloudFront will use for your distribution.
     *
     * Default value is PriceClass_100.
     * See https://aws.amazon.com/cloudfront/pricing/ for full list of supported regions.
     *
     * @stability stable
     */
    readonly priceClass?: cloudfront.PriceClass;
}
/**
 * @stability stable
 */
export declare class CreateBasicSite extends cdk.Construct {
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: SimpleWebsiteConfiguration);
}
/**
 * @stability stable
 */
export declare class CreateCloudfrontSite extends cdk.Construct {
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: SimpleWebsiteConfiguration);
}
